# Contributing

This is Open Source software, so [given enough eyeballs, all bugs are shallow](https://en.wikipedia.org/wiki/Linus%27s_Law). Your contributions are more than welcome.

This project is hosted on [GitHub](https://githhub.com/{{ github_account }}/{{ github_repo_name }}) and these (common) rules apply:

* Do use the [issues tracker](https://githhub.com/{{ github_account }}/{{ github_repo_name }}/issues).
* Let's discuss any proposed change or fix in an issue, so your work is not done in vain - I hate to reject pull requests...
* Create [pull requests](https://githhub.com/{{ github_account }}/{{ github_repo_name }}/pulls) against `next` branch.
* Try to keep pull requests "atomic", and if possible related to an issue.
